aboutsummaryrefslogtreecommitdiff
path: root/src/include/ipxe
diff options
context:
space:
mode:
authorMichael Brown <mcb30@ipxe.org>2012-06-09 18:58:54 +0100
committerMichael Brown <mcb30@ipxe.org>2012-06-09 18:59:41 +0100
commitaf47789ef2276fdb3b081955025b778d16ed2188 (patch)
treeca82a352f68cc65024ff73d657c956cf13e2d878 /src/include/ipxe
parent5482b0abb6518916b4036aafab0d65e7bad7b2e8 (diff)
downloadipxe-af47789ef2276fdb3b081955025b778d16ed2188.zip
ipxe-af47789ef2276fdb3b081955025b778d16ed2188.tar.gz
ipxe-af47789ef2276fdb3b081955025b778d16ed2188.tar.bz2
[tls] Mark security negotiation as a pending operation
Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/include/ipxe')
-rw-r--r--src/include/ipxe/tls.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/include/ipxe/tls.h b/src/include/ipxe/tls.h
index 7de1f19..4273e4e 100644
--- a/src/include/ipxe/tls.h
+++ b/src/include/ipxe/tls.h
@@ -18,6 +18,7 @@ FILE_LICENCE ( GPL2_OR_LATER );
#include <ipxe/sha1.h>
#include <ipxe/sha256.h>
#include <ipxe/x509.h>
+#include <ipxe/pending.h>
/** A TLS header */
struct tls_header {
@@ -240,10 +241,10 @@ struct tls_session {
/** Certificate validator */
struct interface validator;
- /** Client has finished security negotiation */
- unsigned int client_finished;
- /** Server has finished security negotiation */
- unsigned int server_finished;
+ /** Client security negotiation pending operation */
+ struct pending_operation client_negotiation;
+ /** Server security negotiation pending operation */
+ struct pending_operation server_negotiation;
/** TX sequence number */
uint64_t tx_seq;